==> stepfunctions-tasks-1.85.0-sources.jar: software/amazon/awscdk/services/stepfunctions/tasks/InvokeActivity.java <==
package software.amazon.awscdk.services.stepfunctions.tasks;

/**
 * (deprecated) A Step Functions Task to invoke an Activity worker.
 * <p>
 * An Activity can be used directly as a Resource.
 * <p>
 * @deprecated - use `StepFunctionsInvokeActivity`
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.15.0 (build 585166b)", date = "2021-01-14T21:02:43.038Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.tasks.$Module.class, fqn = "@aws-cdk/aws-stepfunctions-tasks.InvokeActivity")
public class InvokeActivity extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.stepfunctions.IStepFunctionsTask {

    protected InvokeActivity(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected InvokeActivity(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param activity This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public InvokeActivity(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.IActivity activity, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivityProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(activity, "activity is required"), props });
    }

    /**
     * @param activity This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public InvokeActivity(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.IActivity activity) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(activity, "activity is required") });
    }

    /**
     * (deprecated) Called when the task object is used in a workflow.
     * <p>
     * @param _task This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StepFunctionsTaskConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.Task _task) {
        return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StepFunctionsTaskConfig.class), new Object[] { java.util.Objects.requireNonNull(_task, "_task is required") });
    }

    /**
     * (deprecated) A fluent builder for {@link software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity> {
        /**
         * @return a new instance of {@link Builder}.
         * @param activity This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public static Builder create(final software.amazon.awscdk.services.stepfunctions.IActivity activity) {
            return new Builder(activity);
        }

        private final software.amazon.awscdk.services.stepfunctions.IActivity activity;
        private software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivityProps.Builder props;

        private Builder(final software.amazon.awscdk.services.stepfunctions.IActivity activity) {
            this.activity = activity;
        }

        /**
         * Maximum time between heart beats.
         * <p>
         * If the time between heart beats takes longer than this, a 'Timeout' error is raised.
         * <p>
         * Default: No heart beat timeout
         * <p>
         * @return {@code this}
         * @param heartbeat Maximum time between heart beats. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder heartbeat(final software.amazon.awscdk.core.Duration heartbeat) {
            this.props().heartbeat(heartbeat);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity build() {
            return new software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity(
                this.activity,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivityProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivityProps.Builder();
            }
            return this.props;
        }
    }
}

==> stepfunctions-tasks-1.97.0-sources.jar: software/amazon/awscdk/services/stepfunctions/tasks/InvokeActivity.java <==
package software.amazon.awscdk.services.stepfunctions.tasks;

/**
 * (deprecated) A Step Functions Task to invoke an Activity worker.
 * <p>
 * An Activity can be used directly as a Resource.
 * <p>
 * @deprecated use `StepFunctionsInvokeActivity`
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.27.0 (build 07d848a)", date = "2021-04-06T14:02:41.523Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.tasks.$Module.class, fqn = "@aws-cdk/aws-stepfunctions-tasks.InvokeActivity")
public class InvokeActivity extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.stepfunctions.IStepFunctionsTask {

    protected InvokeActivity(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected InvokeActivity(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param activity This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public InvokeActivity(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.IActivity activity, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivityProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(activity, "activity is required"), props });
    }

    /**
     * @param activity This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public InvokeActivity(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.IActivity activity) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(activity, "activity is required") });
    }

    /**
     * (deprecated) (deprecated) Called when the task object is used in a workflow.
     * <p>
     * @param _task This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.StepFunctionsTaskConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.Task _task) {
        return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.StepFunctionsTaskConfig.class), new Object[] { java.util.Objects.requireNonNull(_task, "_task is required") });
    }

    /**
     * (deprecated) A fluent builder for {@link software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity> {
        /**
         * @return a new instance of {@link Builder}.
         * @param activity This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public static Builder create(final software.amazon.awscdk.services.stepfunctions.IActivity activity) {
            return new Builder(activity);
        }

        private final software.amazon.awscdk.services.stepfunctions.IActivity activity;
        private software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivityProps.Builder props;

        private Builder(final software.amazon.awscdk.services.stepfunctions.IActivity activity) {
            this.activity = activity;
        }

        /**
         * (deprecated) Maximum time between heart beats.
         * <p>
         * If the time between heart beats takes longer than this, a 'Timeout' error is raised.
         * <p>
         * Default: No heart beat timeout
         * <p>
         * @return {@code this}
         * @param heartbeat Maximum time between heart beats. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder heartbeat(final software.amazon.awscdk.core.Duration heartbeat) {
            this.props().heartbeat(heartbeat);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity build() {
            return new software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivity(
                this.activity,
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivityProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.stepfunctions.tasks.InvokeActivityProps.Builder();
            }
            return this.props;
        }
    }
}
